@@ -139,7 +139,8 @@ void PredictorRegistry::addPredictor(const std::string& predictorName)
 	}
 	else
 	{
-	    logger << ERROR <<  predictor_class_variable_key << " class is unknown." << endl;
+	    logger << ERROR <<  predictor_class_variable_key << " class \""
+		   << predictor_class << "\" is unknown." << endl;
 	}
     }
     catch (PresageException ex) 
@@ -195,7 +196,7 @@ bool PredictorRegistry::Iterator::hasNext() const
 Predictor* PredictorRegistry::Iterator::next()
 {
     Predictor* result = *iter_curr;
-    iter_curr++;
+    ++iter_curr;
     return result;
 }
 
